pub fn selabel<H: FsVerityHashValue>(
fs: &mut FileSystem<H>,
repo: &Repository<H>,
) -> Result<()>Expand description
Applies SELinux security contexts to all files in a filesystem tree.
Reads the SELinux policy from /etc/selinux/config and corresponding policy files, then labels all filesystem nodes with appropriate security.selinux extended attributes.
Arguments
fs- The filesystem to labelrepo- The composefs repository
Returns
Ok(()) if labeling succeeds or if no SELinux policy is found